#source("./Density-tweedie.R")
#
#########################################################################################
#######   GTE shell for specific "classical" precedure (GTE model driver)       #########
#######   Computes model densities or specific target function values           #########
#######   for given parameter estimates                                         #########
#######                                                                         #########
#######   data  - model data, expected to be model.frame with family attribute; #########
#######   pars  - model estimate.                                               #########
#######           Current parameters extracted via coef function;               #########
#######                                                                         #########
#######   value - Individual(per case) Likelihoods or Target value              #########
#######                 not loglikelihoods!                                     #########
#########################################################################################

Density =function(data, fit, ...)
{
        if(fit$family[1]=="Tweedie") {
                mu = predict(fit, newdata=data, type="response")
                phi= predict(fit$dispersion.fit, newdata=data, type="response")
                y  = data[,all.vars(model)[1]]
                #q = dtweedie.series(y, power=1, mu=mu, phi=phi)        #problem?
                d  = 2*(y*log(y/mu)-(y-mu))
                q  = -(log(2*pi*phi*y)+d/phi)/2
        } else stop("Incorrect model family")

return(list(lik=exp(q)))                                                        #return individual likelihoods - not log likelihoods!!
}

Tprint=function(data,fit,print=T)                                               #additional print of some information about model and data
{
        mu  = predict(fit, newdata=data, type="response")
        phi = predict(fit$dispersion.fit, newdata=data, type="response")
        y   = data[,all.vars(fit$terms)[1]]
        d   = 2*(y*log(y/mu)-(y-mu))
        q   = -(log(2*pi*phi*y)+d/phi)/2

        if(print) print(cbind(data,mu=mu,phi=phi,q=q))

        return(invisible(q))
}
