#source("./Simple-example-tweedie.R")

require(dglm)                                                                   # required packages!
require(tweedie)                                                                
#
#       Common and model specific functions required
#
source("./Generation-tweedie.R")                                                # load data generator
source("./Estimate-tweedie.R")                                                  # load GTE shell for classical estimation procedure/script
source("./Density-tweedie.R")                                                   # script to computes densities or specific target function values casewise
source("../sys/GTE.R")                                                          # General GTE script
source("../sys/summary.GTE.R")                                                  # Additional GTE class functions
source("../sys/plot.GTE.R")                                                     # Additional GTE class functions
source("../sys/Progress.Bar.R")                                                 # additional progress bar script in case of higher message level
#
nit=300                                                                         # number of GTE cycles
## result may be obtained more quickly by applying seed values.
## tested for R-2.12.2!
seeds=c(1,5,17,123)
set.seed(seeds[1]); nit = 15;
#
#       Generate contaminated data ACCORDING ARTICLE....
#       and creating datafile
#
        datafile= "tweedie.dat"
        family  = "tweedie"                                                     # model family
        model   = Y ~ A + B                                                     # model formula
        dmodel  = d ~ D
        method  = c("ml","reml")[2]                                             # selectt DGLM method
        Generation(n=40, N=4, nvar=4, model, dmodel, family, method, Estimate, datafile)
#
#       Several ways to analyse this data:
#
        data=read.table(file=datafile, header = TRUE)                           # read data
#       data=data[,-ncol(data)]                                                 # test for missing "c"
#
#       Original procedure fit with no outliers in data:

if(!is.null(data$c)) {                                                          # if information about outliers is available in "c" variable
est.true= NULL
est.true= Estimate(data=data,ind=data$c==1, model=model, dmodel=dmodel, family=family, method=method)
par.true= cbind(NULL,est.true=coef(est.true))
}
#
#       Original procedure fit with outliers in data:
est.cont= NULL
est.cont= Estimate(data=data,ind=NULL, model=model, dmodel=dmodel, family=family, method=method)
par.cont= cbind(NULL,est.cont=coef(est.cont))
#
#       GTE procedure fit with outliers in data:
est.gte = NULL
est.gte = GTE(kStar=10, kTrim=36, data=data, msglvl=1, nit=nit, result=est.gte,
        Density=Density, Estimate=Estimate, model=model, dmodel=dmodel, family=family, method=method)
#
if(!is.null(est.gte)) {
        par.gte = cbind(NULL,est.gte=coef.gte(est.gte))
        print(summary.gte(est.gte))
        print("GTE parameter estimate:")
        print(coef.gte(est.gte))
        plot.gte(est.gte)
#
#       Finalal fit by original procedure with GTE weights
        est.final = NULL
        est.final = Estimate(data=data,ind=est.gte$indbest, model=model, dmodel=dmodel, family=family, method=method)
        par.final = cbind(NULL,est.final=coef(est.final))
        print("All parameter estimates obtained previously:")
        print(round(cbind(par.true, par.cont, par.gte, par.final),6))
} else  print("No estimate! Computational error!")
