#source("./Density-gamma.R")
#
#########################################################################################
#######   GTE shell for specific "classical" precedure (GTE model driver)       #########
#######   Computes model densities or specific target function values           #########
#######   for given parameter estimates                                         #########
#######                                                                         #########
#######   data  - model data, expected to be model.frame with family attribute; #########
#######   pars  - model estimate.                                               #########
#######           Current parameters extracted via coef function;               #########
#######                                                                         #########
#######   value - Individual(per case) Likelihoods or Target value              #########
#######                 not loglikelihoods!                                     #########
#########################################################################################

Density =function(data, fit, ...)
{
        if(fit$family[1]=="Gamma") {
                mu = predict(fit, newdata=data, type="response")
                fi = predict(fit$dispersion.fit, newdata=data, type="response")
                y  = data[,all.vars(model)[1]]
                q  = -log(2*pi*fi*y^2)/2-(y/mu-log(y/mu)-1)/fi
        } else stop("Incorrect model family")

return(list(lik=exp(q)))                                                        #return individual likelihoods - not log likelihoods!!
}

Tprint=function(data,fit,print=T)                                               #additional print of some information about model and data
{
        mu = predict(fit, newdata=data, type="response")
        fi = predict(fit$dispersion.fit, newdata=data, type="response")
        y  = data[,all.vars(fit$terms)[1]]
        q  = -log(2*pi*fi*y^2)/2-(y/mu-log(y/mu)-1)/fi

        if(print) print(cbind(data,mu=mu,fi=fi,q=q))

return(invisible(q))
}
