#source("./Generation-gauss.R")

#Generates data examples used in article.......

Generation=function(n, N, nvar, model, dmodel, family, method, Estimate, datafile="gauss.dat", plotfile=NULL, plotdata=T) {

require(dglm)

#parameters for data generation used in article.......
#
#       n       =40 -number of samples
#       N       =4  -number of outliers
#       nvar    =4  -control number of variables
#       model   =Y ~ A + B
#       dmodel  =d ~ D
#       family  ="gauss"
#       method  =c("ml","reml")[2]
#       Estimate=source("Estimate-gauss.R", special function
#       datafile=output data file
#       plotfile=output plotfile of generated data
#       plotdata=flag to plot data

#Sometimes  generating of sample data is not a trivial task!
#We need to ensure that generated data are appropriate for used basic
#estimation procedures - in this case fitjoint from JointModeling package.
#fitjoint is very sensitive and we need to use maximum defences,
#including try() and capture.out() R tools (see Estimate-gauss.R script)

par.true=NULL
par.cont=NULL

while(is.null(par.cont) || is.null(par.true)) {                                 # repeat next lines untill obtain estimates
#       Generate regular data. No contamination!.................................

A = rnorm(n,0,1)
B = rnorm(n,0,1)
D = rnorm(n,0,1)

mu = (1 + 1*A + 1*B)                            # generate  random distribution parameters
sd = sqrt(exp(-4-4*D))

Y = rnorm(n, mu, sd)                            # generate regular Obsevation
data=cbind(Y=Y, A=A, B=B, D=D, c=rep(1,n), mu=mu, sd=sd)
data=as.data.frame(data)
data=round(data,4)
if(nvar!=ncol(data)-3) stop("Incorrectly specified number of variables!")

#       control estimation

est.true=NULL
est.true = Estimate(data=data, ind=NULL, model=model, dmodel=dmodel, family=family, method=method)
if(is.null(est.true)) {print("skip it 1!"); next()}
par.true = cbind(NULL,est.true=coef(est.true))
print("Parameter estimation using non contaminated data and dglm function")
print(par.true)
#
#       Contaminate initial data.................................................
#
if(N!=4) stop("Incorrect number of outliers for data generation!")              # number of outlier set in main procedure
#
sgn=round(runif(N))*2-1
data$Y[1]=data$Y[1]+10*sgn[1]   #14
data$A[2]=data$A[2]+ 5*sgn[2]   #10
data$B[3]=data$B[3]+ 5*sgn[3]   #10
data$D[4]=data$D[4]+10*sgn[4]   #14
data$c[1:4]=2                                                                   # mark generated outliers in data
#
#       control estimation
#
est.cont=NULL
est.cont = Estimate(data=data, ind=NULL, model=model, dmodel=dmodel, family=family, method=method)
if(is.null(est.cont)) {print("skip it 2!"); next()}
par.cont = cbind(NULL,est.cont=coef(est.cont))
print("Parameter estimation using contaminated data and dglm function")
print(par.cont)
#
#       Save generated data
#
        if(!is.null(datafile)) {
                write.table(data,file=datafile,row.names=F,sep="\t")
                print(paste("simulated contaminated data is written as",datafile))
        }
#
        if(!is.null(plotfile)|plotdata) {
        #       Plot generated data
                type=c("png","pdf","eps")
                plot(data[,1:nvar],col=data$c,pch=23-2*data$c)
                title("Generated data with outliers",line=3,col.main="red")
                if(!is.null(plotfile)) for(typ in type) savePlot(file=paste(plotfile,typ,sep="."),type=typ)
        }
#
}
return(invisible(NULL))
}
