#source("./Simple-example-gauss.R")

require(JointModeling)                                                          # required package!
#
#       Common and model specific functions required
#
source("./Generation-gauss.R")                                                  # load data generator
source("./Estimate-gauss.R")                                                    # load GTE shell for classical estimation procedure/script
source("./Density-gauss.R")                                                     # script to computes densities or specific target function values casewise
source("../sys/GTE.R")                                                          # General GTE script
source("../sys/summary.gte.R")                                                  # Additional tle class functions
source("../sys/plot.gte.R")                                                     # Additional tle class functions
source("../sys/Progress.Bar.R")                                                 # additional progress bar script in case of higher message level
#
nit=100                                                                         # number of GTE cycles
## result may be obtained more quickly by applying seed values.
## tested for R-2.12.2!
seeds=c(31,1,20)
set.seed(seeds[1]); nit = 15;                                                   # number of GTE cycles
#
#       Generate contaminated data ACCORDING ARTICLE....
#       and creating datafile
#
        datafile= "gauss.dat"
        family  = "gauss"                                                       # model family
        model   = Y ~ A + B                                                     # model formula
        dmodel  = d ~ D
        method  = NULL
        Generation(n=40, N=4, nvar=4, model, dmodel, family, method, Estimate, datafile)
#
#       Several ways to analyse this data:
#
        data=read.table(file=datafile, header = TRUE)                           # read data
#
#       Original procedure fit with no outliers in data:

if(!is.null(data$c)) {                                                          # if information about outliers is available in "c" variable
est.true= NULL
est.true= Estimate(data=data,ind=data$c==1, model=model, dmodel=dmodel, family=family)
par.true= cbind(NULL,est.true=coef(est.true))
}
#
#       Original procedure fit with outliers in data:
est.cont= NULL
est.cont= Estimate(data=data,ind=NULL, model=model, dmodel=dmodel, family=family)
par.cont= cbind(NULL,est.cont=coef(est.cont))
#
#       GTE procedure fit with outliers in data:
est.gte = NULL
est.gte = GTE(kStar=10, kTrim=36, data=data, msglvl=1, nit=nit, result=est.gte,
        Density=Density, Estimate=Estimate, model=model, dmodel=dmodel, family=family)
#
if(!is.null(est.gte)) {
        par.gte = cbind(NULL,est.gte=coef.gte(est.gte))
        print(summary.gte(est.gte))
        print("GTE parameter estimate:")
        print(coef.gte(est.gte))
        plot.gte(est.gte)
#
#       Finalal fit by original procedure with GTE weights
        est.final = NULL
        est.final = Estimate(data=data,ind=est.gte$indbest, model=model, dmodel=dmodel, family=family)
        par.final = cbind(NULL,est.final=coef(est.final))
        print("All parameter estimates obtained previously:")
        print(round(cbind(par.true, par.cont, par.gte, par.final),6))
} else  print("No estimate! Computational error!")
